Method: Thor::Base.shell

Defined in:
lib/vendor/thor/lib/thor/shell.rb

.shellObject

Returns the shell used in all Thor classes. If you are in a Unix platform it will use a colored log, otherwise it will use a basic one without color.



9
10
11
12
13
14
15
# File 'lib/vendor/thor/lib/thor/shell.rb', line 9

def self.shell
  @shell ||= if Config::CONFIG['host_os'] =~ /mswin|mingw/
    Thor::Shell::Basic
  else
    Thor::Shell::Color
  end
end